package controllers

import (
	"encoding/json"
	"hongze/hongze_cygxzs/models"
	"hongze/hongze_cygxzs/utils"
	"strconv"
	"strings"
	"time"
)

type UserController struct {
	BaseAuthController
}

type UserCommonController struct {
	BaseCommonController
}

// @Title 获取用户的选择详情
// @Description 获取用户的选择详情接口
// @Success 200 {object}  models.CygxXzsChooseSendResp
// @router /choose/detail [get]
func (this *UserController) ChooseDetail() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，用户信息为空"
		br.Ret = 408
		return
	}
	resp := new(models.CygxXzsChooseSendResp)
	var condition string
	var pars []interface{}
	mobile := user.Mobile
	if mobile == "" {
		br.Ret = 200
		br.Success = true
		br.Msg = "获取成功"
		br.Data = resp
	}
	permissionId, err := models.GetCompanyPermissionId(user.CompanyId)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "GetCompanyPermissionId,Err:" + err.Error()
		return
	}
	if permissionId == "" {
		br.Ret = 200
		br.Success = true
		br.Msg = "获取成功"
		br.Data = resp
	}
	mapIndustrial := make(map[int][]*models.IndustrialManagementRep)
	mapFllow := make(map[int]int)
	ampCheckList := make(map[int][]int, 0)
	permissionIdList := make([]string, 0)
	fllowList, err := models.GetCygxIndustryFllowList(mobile)
	if err != nil && err.Error() != utils.ErrNoRow() {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取客户信息失败,Err:" + err.Error()
		return
	}

	for _, v := range fllowList {
		mapFllow[v.IndustrialManagementId] = v.IndustrialManagementId
	}
	industrialList, err := models.GetindustrialManagement()
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取产业信息失败,Err:" + err.Error()
		return
	}
	celueList, err := models.GetReportMappingStrategyAll()
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取产业信息失败,Err:" + err.Error()
		return
	}

	for _, v := range industrialList {
		if mapFllow[v.IndustrialManagementId] > 0 {
			v.IsFllow = true
			//添加所关注的行业赛道
			ampCheckList[v.ChartPermissionId] = append(ampCheckList[v.ChartPermissionId], v.IndustrialManagementId)
		}
		mapIndustrial[v.ChartPermissionId] = append(mapIndustrial[v.ChartPermissionId], v)
	}
	slicepermissionId := strings.Split(permissionId, ",")
	if len(slicepermissionId) > 0 {
		for _, v := range slicepermissionId {
			permissionIdList = append(permissionIdList, v)
		}
		condition += ` AND chart_permission_id IN (` + utils.GetOrmInReplace(len(slicepermissionId)) + ` )  `
		pars = append(pars, permissionIdList)
	}
	permissionList, err := models.GetChartPermissionAll(condition, pars)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取产业信息失败,Err:" + err.Error()
		return
	}
	for k, v := range permissionList {
		if v.PermissionName == utils.CE_LUE_NAME {
			permissionList[k].List = celueList
			permissionList[k].AllTracks = "全系列报告"
		} else {
			permissionList[k].AllTracks = "全部赛道"
			if len(mapIndustrial[v.ChartPermissionId]) == 0 {
				permissionList[k].List = make([]*models.IndustrialManagementRep, 0)
			} else {
				permissionList[k].List = mapIndustrial[v.ChartPermissionId]
			}
			if len(ampCheckList[v.ChartPermissionId]) == 0 {
				permissionList[k].CheckList = make([]int, 0)
			} else {
				permissionList[k].CheckList = ampCheckList[v.ChartPermissionId]
			}
		}

	}
	count, err := models.GetXzsChooseSendCountByMobile(mobile)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "GetXzsChooseSendCountByMobile,Err:" + err.Error()
		return
	}
	if count == 0 {
		resp.IsObjective = 1
		resp.IsSubjective = 1
	} else {
		detail, err := models.GetCygxXzsChooseSendByMobile(mobile)
		if err != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "GetCygxXzsChooseSendByMobile,Err:" + err.Error()
			return
		}
		resp.IsObjective = detail.IsObjective
		resp.IsSubjective = detail.IsSubjective
		resp.IsRefuse = detail.IsRefuse
	}
	resp.List = permissionList
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 提交用户的选择详情
// @Description 提交用户的选择详情接口
// @Param	request	body models.SubmitChooseSendResp true "type json string"
// @Success 200 {object}  models.CygxXzsChooseSendResp
// @router /choose/submit [post]
func (this *UserController) ChooseSubmit() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，用户信息为空"
		br.Ret = 408
		return
	}
	if user.Mobile == "" {
		br.Msg = "提交失败！"
		br.ErrMsg = "提交失败，手机号不能为空"
		return
	}
	var req models.SubmitChooseSendResp
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}
	var industrialManagementIds string
	industrialManagementList := req.List
	for _, v := range industrialManagementList {
		if v.ChartPermissionId != 23 {
			industrialManagementIds += v.IndustrialManagementIds + ","
		}
	}
	industrialManagementIds = strings.TrimRight(industrialManagementIds, ",")
	sliceIndustrial := strings.Split(industrialManagementIds, ",")
	var itemsFllow []*models.CygxIndustryFllow
	for _, v := range sliceIndustrial {
		item := new(models.CygxIndustryFllow)
		industrialManagementId, _ := strconv.Atoi(v)
		item.IndustrialManagementId = industrialManagementId
		item.UserId = user.UserId
		item.Mobile = user.Mobile
		item.Email = user.Email
		item.CompanyId = user.CompanyId
		item.CompanyName = user.CompanyName
		item.RealName = user.RealName
		item.Type = 1
		item.CreateTime = time.Now()
		item.ModifyTime = time.Now()
		item.Source = 2
		itemsFllow = append(itemsFllow, item)
	}

	mobile := user.Mobile
	item := new(models.CygxXzsChooseSend)
	item.UserId = user.UserId
	item.Mobile = user.Mobile
	item.Email = user.Email
	item.CompanyId = user.CompanyId
	item.CompanyName = user.CompanyName
	item.RealName = user.RealName
	item.CreateTime = time.Now()
	item.ModifyTime = time.Now()
	item.IsRefuse = req.IsRefuse
	item.IsSubjective = req.IsSubjective
	item.IsObjective = req.IsObjective
	count, err := models.GetXzsChooseSendCountByMobile(mobile)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "GetXzsChooseSendCountByMobile,Err:" + err.Error()
		return
	}
	//如果有记录就新增，没有记录就修改
	if count == 0 {
		err = models.AddCygxXzsChooseSend(item, itemsFllow)
	} else {
		err = models.UpdateCygxXzsChooseSend(item, itemsFllow)
	}
	if err != nil {
		br.Msg = "保存失败！"
		br.ErrMsg = "保存失败！,Err:" + err.Error()
		return
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "保存成功"
}
