package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type CygxXzsChooseSend struct {
	Id           int       `orm:"column(id);pk"`
	UserId       int       `description:"用户ID"`
	Mobile       string    `description:"手机号"`
	Email        string    `description:"邮箱"`
	CompanyId    int       `description:"公司id"`
	CompanyName  string    `description:"公司名称"`
	RealName     string    `description:"用户实际名称"`
	IsRefuse     int       `description:"是否拒绝推送，0否、1是  如果为1 则不做任何推送"`
	IsSubjective int       `description:"是否选择主观推送， 1 是 、 0否"`
	IsObjective  int       `description:"是否选择客观推送， 1 是 、 0否"`
	CreateTime   time.Time `description:"创建时间"`
	ModifyTime   time.Time `description:"更新时间"`
}

type CygxXzsChooseSendResp struct {
	IsRefuse     int `description:"是否拒绝推送，0否、1是  如果为1 则不做任何推送"`
	IsSubjective int `description:"是否选择主观推送， 1 是 、 0否"`
	IsObjective  int `description:"是否选择客观推送， 1 是 、 0否"`
	List         []*ChartPermissionResp
}

type SubmitChooseSendResp struct {
	IsRefuse     int `description:"是否拒绝推送，0否、1是  如果为1 则不做任何推送"`
	IsSubjective int `description:"是否选择主观推送， 1 是 、 0否"`
	IsObjective  int `description:"是否选择客观推送， 1 是 、 0否"`
	List         []*IndustrialManagementIdResp
}

type IndustrialManagementIdResp struct {
	IndustrialManagementIds string `description:"产业ID 多个用 ，隔开"`
	ChartPermissionId       int    `description:"权限id"`
}

//添加
func AddCygxXzsChooseSend(item *CygxXzsChooseSend, itemsFllow []*CygxIndustryFllow) (err error) {
	o, err := orm.NewOrm().Begin()
	if err != nil {
		return
	}
	defer func() {
		if err == nil {
			o.Commit()
		} else {
			o.Rollback()
		}
	}()

	//删除原有的关注记录
	sql := `DELETE FROM cygx_industry_fllow WHERE mobile = ?`
	_, err = o.Raw(sql, item.Mobile).Exec()

	//批量添加新的关注记录
	_, err = o.InsertMulti(len(itemsFllow), itemsFllow)
	if err != nil {
		return err
	}

	//添加所勾选的消息类型
	_, err = o.Insert(item)
	return
}

//获取数量
func GetXzsChooseSendCountByMobile(mobile string) (count int, err error) {
	sql := ` SELECT  COUNT(1) AS count  FROM cygx_xzs_choose_send WHERE mobile = ? `
	o := orm.NewOrm()
	err = o.Raw(sql, mobile).QueryRow(&count)
	return
}

//添加
func UpdateCygxXzsChooseSend(item *CygxXzsChooseSend, itemsFllow []*CygxIndustryFllow) (err error) {
	o, err := orm.NewOrm().Begin()
	if err != nil {
		return
	}
	defer func() {
		if err == nil {
			o.Commit()
		} else {
			o.Rollback()
		}
	}()

	//删除原有的关注记录
	sql := `DELETE FROM cygx_industry_fllow WHERE mobile = ?`
	_, err = o.Raw(sql, item.Mobile).Exec()

	//批量添加新的关注记录
	_, err = o.InsertMulti(len(itemsFllow), itemsFllow)
	if err != nil {
		return err
	}

	//修改现有的类型
	updateParams := make(map[string]interface{})
	updateParams["UserId"] = item.UserId
	updateParams["Mobile"] = item.Mobile
	updateParams["Email"] = item.Email
	updateParams["CompanyId"] = item.CompanyId
	updateParams["CompanyName"] = item.CompanyName
	updateParams["RealName"] = item.RealName
	updateParams["ModifyTime"] = time.Now()
	updateParams["IsRefuse"] = item.IsRefuse
	updateParams["IsSubjective"] = item.IsSubjective
	updateParams["IsObjective"] = item.IsObjective
	whereParam := map[string]interface{}{"mobile": item.Mobile}
	err = UpdateByExpr(CygxXzsChooseSend{}, whereParam, updateParams)
	return
}

//根据用户openid获取token
func GetCygxXzsChooseSendByMobile(mobile string) (item *CygxXzsChooseSend, err error) {
	sql := `SELECT * FROM cygx_xzs_choose_send WHERE mobile=?  LIMIT 1 `
	o := orm.NewOrm()
	err = o.Raw(sql, mobile).QueryRow(&item)
	return
}
